@@ -124,11 +124,11 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         from configuration, neutron service is stopped. Admin must delete
         resources prior to removing providers from configuration.
         """
-        loadbalancers = self.db.get_loadbalancers(context)
+        used_provider_names = (
+            self.db.get_provider_names_used_in_loadbalancers(context))
         lost_providers = set(
-            [lb.provider.provider_name
-             for lb in loadbalancers
-             if lb.provider.provider_name not in provider_names])
+            [name for name in used_provider_names
+                if name not in provider_names])
         # resources are left without provider - stop the service
         if lost_providers:
             msg = ("Delete associated load balancers before "
@@ -443,14 +443,14 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         old_lb = self.db.get_loadbalancer(context, id)
         if old_lb.listeners:
             raise loadbalancerv2.EntityInUse(
-                entity_using=models.Listener.NAME,
+                entity_using=models.LoadBalancer.NAME,
                 id=old_lb.listeners[0].id,
-                entity_in_use=models.LoadBalancer.NAME)
+                entity_in_use=models.Listener.NAME)
         if old_lb.pools:
             raise loadbalancerv2.EntityInUse(
-                entity_using=models.PoolV2.NAME,
+                entity_using=models.LoadBalancer.NAME,
                 id=old_lb.pools[0].id,
-                entity_in_use=models.LoadBalancer.NAME)
+                entity_in_use=models.PoolV2.NAME)
         self.db.test_and_set_status(context, models.LoadBalancer, id,
                                     n_constants.PENDING_DELETE)
         driver = self._get_driver_for_provider(old_lb.provider.provider_name)
@@ -462,8 +462,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         return self.db.get_loadbalancer(context, id).to_api_dict()
 
     def get_loadbalancers(self, context, filters=None, fields=None):
-        return [loadbalancer.to_api_dict() for loadbalancer in
-                self.db.get_loadbalancers(context, filters=filters)]
+        return self.db.get_loadbalancers_as_api_dict(context, filters=filters)
 
     def _validate_tls(self, listener, curr_listener=None):
         def validate_tls_container(container_ref):
@@ -500,10 +499,13 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                         cert_container.get_private_key_passphrase()),
                     intermediates=cert_container.get_intermediates())
             except Exception as e:
-                cert_mgr.delete_cert(
-                    project_id=tenant_id,
-                    cert_ref=container_ref,
-                    resource_ref=cert_mgr.get_service_url(lb_id))
+                try:
+                    cert_mgr.delete_cert(
+                        project_id=tenant_id,
+                        cert_ref=container_ref,
+                        resource_ref=cert_mgr.get_service_url(lb_id))
+                except Exception:
+                    LOG.error('Unable to delete cert', exc_info=True)
                 raise loadbalancerv2.TLSContainerInvalid(
                     container_id=container_ref, reason=str(e))
 
@@ -604,7 +606,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
                     curr_listener['default_tls_container_id'])
             if 'sni_container_refs' not in listener:
                 listener['sni_container_ids'] = [
-                    container.tls_container_id for container in (
+                    container['tls_container_id'] for container in (
                         curr_listener['sni_containers'])]
 
             tls_containers_changed = False
@@ -659,8 +661,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         return self.db.get_listener(context, id).to_api_dict()
 
     def get_listeners(self, context, filters=None, fields=None):
-        return [listener.to_api_dict() for listener in self.db.get_listeners(
-            context, filters=filters)]
+        return self.db.get_listeners_as_api_dict(
+            context, filters=filters)
 
     def create_pool(self, context, pool):
         pool = pool.get('pool')
@@ -683,6 +685,11 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             if db_l.default_pool_id:
                 raise sharedpools.ListenerDefaultPoolAlreadySet(
                     listener_id=db_l.id, pool_id=db_l.default_pool_id)
+            if ((pool['protocol'], db_l.protocol)
+                not in lb_const.LISTENER_POOL_COMPATIBLE_PROTOCOLS):
+                raise loadbalancerv2.ListenerPoolProtocolMismatch(
+                    listener_proto=db_l.protocol,
+                    pool_proto=pool['protocol'])
         if not lb_id:
             raise sharedpools.PoolMustHaveLoadbalancer()
         pool['loadbalancer_id'] = lb_id
@@ -738,9 +745,9 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         old_pool = self.db.get_pool(context, id)
         if old_pool.healthmonitor:
             raise loadbalancerv2.EntityInUse(
-                entity_using=models.HealthMonitorV2.NAME,
+                entity_using=models.PoolV2.NAME,
                 id=old_pool.healthmonitor.id,
-                entity_in_use=models.PoolV2.NAME)
+                entity_in_use=models.HealthMonitorV2.NAME)
         self.db.test_and_set_status(context, models.PoolV2, id,
                                     n_constants.PENDING_DELETE)
         db_pool = self.db.get_pool(context, id)
@@ -750,8 +757,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         self._call_driver_operation(context, driver.pool.delete, db_pool)
 
     def get_pools(self, context, filters=None, fields=None):
-        return [pool.to_api_dict() for pool in self.db.get_pools(
-            context, filters=filters)]
+        return self.db.get_pools_as_api_dict(
+            context, filters=filters)
 
     def get_pool(self, context, id, fields=None):
         return self.db.get_pool(context, id).to_api_dict()
@@ -822,8 +829,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         if not filters:
             filters = {}
         filters['pool_id'] = [pool_id]
-        return [mem.to_api_dict() for mem in self.db.get_pool_members(
-            context, filters=filters)]
+        return self.db.get_pool_members_as_api_dict(
+            context, filters=filters)
 
     def get_pool_member(self, context, id, pool_id, fields=None):
         self._check_pool_exists(context, pool_id)
@@ -894,8 +901,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         return self.db.get_healthmonitor(context, id).to_api_dict()
 
     def get_healthmonitors(self, context, filters=None, fields=None):
-        return [hm.to_api_dict() for hm in self.db.get_healthmonitors(
-            context, filters=filters)]
+        return self.db.get_healthmonitors_as_api_dict(
+            context, filters=filters)
 
     def stats(self, context, loadbalancer_id):
         lb = self.db.get_loadbalancer(context, loadbalancer_id)
@@ -965,8 +972,8 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             self.db.delete_l7policy(context, id)
 
     def get_l7policies(self, context, filters=None, fields=None):
-        return [policy.to_api_dict() for policy in self.db.get_l7policies(
-            context, filters=filters)]
+        return self.db.get_l7policies_as_api_dict(
+            context, filters=filters)
 
     def get_l7policy(self, context, id, fields=None):
         return self.db.get_l7policy(context, id).to_api_dict()
@@ -1034,13 +1041,13 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             self._call_driver_operation(context, driver.l7rule.delete,
                                         rule_db)
         else:
-            self.db.delete_l7policy_rule(context, id, l7policy_id)
+            self.db.delete_l7policy_rule(context, id)
 
     def get_l7policy_rules(self, context, l7policy_id,
                            filters=None, fields=None):
         self._check_l7policy_exists(context, l7policy_id)
-        return [rule.to_api_dict() for rule in self.db.get_l7policy_rules(
-            context, l7policy_id, filters=filters)]
+        return self.db.get_l7policy_rules_as_api_dict(
+            context, l7policy_id, filters=filters)
 
     def get_l7policy_rule(self, context, id, l7policy_id, fields=None):
         self._check_l7policy_exists(context, l7policy_id)
